==> GeneticsBase_1.0.0.tar.gz: GeneticsBase/man/LD-class.Rd <==
\name{LD-class}
\docType{class}
\alias{LD-class}
\alias{head,LD-method}
\alias{html,LD-method}
\alias{latex,LD-method}
\alias{left,LD-method}
\alias{plot,LD-method}
\alias{right,LD-method}
\alias{show,LD-method}
\alias{tail,LD-method}

\title{Class "LD" ~~~ }
\description{	 ~~ A concise (1-5 lines) description of what the class is.  ~~}
\section{Objects from the Class}{
Objects can be created by calls of the form \code{new("LD", ...)}.
	 ~~ describe objects here ~~ 
}
\section{Slots}{
	 \describe{
    \item{\code{call}:}{Function call used to generate this object.}
    \item{\code{D}:}{Linkage disequilibrium estimate}
    \item{\code{D'}:}{Scaled linkage disequilibrium estimate }
    \item{\code{r}:}{Correlation coefficient}
    \item{\code{R^2}:}{squared correlation coefficient}
    \item{\code{n}:}{Number of observations}
    \item{\code{X^2}:}{Chi-square statistic for linkage
  equilibrium (i.e., D=D'=corr=0)}
    \item{\code{P-value}:}{Chi-square p-value for marker independence}
    \item{\code{LOD}:}{LOD scores}
  }
}
\section{Methods}{
  \describe{
    \item{head}{\code{signature(x = "LD")}: ... }
    \item{html}{\code{signature(x = "LD")}: ... }
    \item{latex}{\code{signature(x = "LD")}: ... }
    \item{left}{\code{signature(x = "LD")}: ... }
    \item{plot}{\code{signature(x = "LD")}: ... }
    \item{right}{\code{signature(x = "LD")}: ... }
    \item{show}{\code{signature(object = "LD")}: ... }
    \item{tail}{\code{signature(x = "LD")}: ... }
	 }
}
\author{
  Gregory R. Warnes \email{warnes@bst.rochester.edu} and
  Nitin Jain \email{nitin.jain@pfizer.com}
}
\note{ ~~further notes~~ }
\seealso{
}
\examples{
##---- Should be DIRECTLY executable !! ----
}
\keyword{classes}

==> GeneticsBase_1.14.0.tar.gz: GeneticsBase/man/LD-class.Rd <==
\name{LD-class}
\docType{class}
\alias{LD-class}
\alias{head,LD-method}
\alias{html,LD-method}
\alias{latex,LD-method}
\alias{left,LD-method}
\alias{plot,LD-method}
\alias{right,LD-method}
\alias{show,LD-method}
\alias{tail,LD-method}

\title{Class "LD" ~~~ }
\description{	 ~~ A concise (1-5 lines) description of what the class is.  ~~}
\section{Objects from the Class}{
Objects can be created by calls of the form \code{new("LD", ...)}.
	 ~~ describe objects here ~~ 
}
\section{Slots}{
	 \describe{
    \item{\code{call}:}{Function call used to generate this object.}
    \item{\code{D}:}{Linkage disequilibrium estimate}
    \item{\code{\special{D'}}:}{Scaled linkage disequilibrium estimate }
    \item{\code{r}:}{Correlation coefficient}
    \item{\code{R^2}:}{squared correlation coefficient}
    \item{\code{n}:}{Number of observations}
    \item{\code{X^2}:}{Chi-square statistic for linkage
  equilibrium (i.e., D=\special{D'}=corr=0)}
    \item{\code{P-value}:}{Chi-square p-value for marker independence}
    \item{\code{LOD}:}{LOD scores}
  }
}
\section{Methods}{
  \describe{
    \item{head}{\code{signature(x = "LD")}: ... }
    \item{html}{\code{signature(x = "LD")}: ... }
    \item{latex}{\code{signature(x = "LD")}: ... }
    \item{left}{\code{signature(x = "LD")}: ... }
    \item{plot}{\code{signature(x = "LD")}: ... }
    \item{right}{\code{signature(x = "LD")}: ... }
    \item{show}{\code{signature(object = "LD")}: ... }
    \item{tail}{\code{signature(x = "LD")}: ... }
	 }
}
\author{
  Gregory R. Warnes \email{warnes@bst.rochester.edu} and
  Nitin Jain \email{nitin.jain@pfizer.com}
}
\note{ ~~further notes~~ }
\seealso{
}
\examples{
##---- Should be DIRECTLY executable !! ----
}
\keyword{classes}
